@@ -326,8 +326,9 @@ class UsersModel(QtGui.QStandardItemModel):
         self.parent = parent
         self.setHeaders()
         self.users = users
-        for user in users:
-            self.addUser(user["username"], "u#" + unicode(user["id"]))
+        if users != False:
+            for user in users:
+                self.addUser(user["username"], "u#" + unicode(user["id"]))
 
     def setHeaders(self):
         self.setColumnCount(2)
@@ -589,7 +590,7 @@ class NewUserWidget(QtGui.QDialog):
         # Add user
         status = addUser(username, admin)
         # Reload user list if no error
-        if not status["error"]:
+        if status != False:
             self.parent.loadUserList()
             self.done(status["user_id"])
         else:
