@@ -51,6 +51,9 @@ import shutil
 import os
 from sflvault.clientqt.lib.error import *
 from sflvault.clientqt.lib.auth import *
+import platform
+import shlex
+
 
 
 class MainWindow(QtGui.QMainWindow):
@@ -144,13 +147,18 @@ class MainWindow(QtGui.QMainWindow):
         ## new service
         QtCore.QObject.connect(self.menubar.newserv, QtCore.SIGNAL("triggered(bool)"), self.editService)
 
+        geometry = self.settings.value("SFLvault-qt4/binsavewindow").toByteArray()
+        self.restoreGeometry(geometry)
+
 
     def closeEvent(self, event):
         if self.settings.value("SFLvault-qt4/hide").toInt()[0] == QtCore.Qt.Checked:
             event.ignore()
+            state = QtCore.QVariant(self.saveGeometry())
+            self.settings.setValue("SFLvault-qt4/binsavewindow", state)
             self.hide()
         elif self.settings.value("SFLvault-qt4/savewindow").toInt()[0] == QtCore.Qt.Checked:
-            state = QtCore.QVariant(self.saveState())
+            state = QtCore.QVariant(self.saveGeometry())
             self.settings.setValue("SFLvault-qt4/binsavewindow", state)
 
     def searchWaiting(self, research):
@@ -325,7 +333,7 @@ class MainWindow(QtGui.QMainWindow):
 
         options["port"] = port
         options["protocol"] = protocol
-        options["vaultid"] = service["services"][-1]["id"]
+        options["vaultid"] = int(service["services"][-1]["id"])
         if tunnel:
             # TODO Fix option
             options["vaultconnect"] = "sflvault connect %s -- %s" % (options["vaultid"], tunnel)
@@ -334,25 +342,29 @@ class MainWindow(QtGui.QMainWindow):
         # Show Tooltip if checked in config
         tooltip, bool = self.settings.value("protocols/" + protocol + "/tooltip").toInt()
         if (bool and tooltip == QtCore.Qt.Checked) or \
-            not self.settings.value("protocols/" + protocol + "/command").toString()\
-            or show_tooltip:
+           not self.settings.value("protocols/" + protocol + "/command").toString()\
+           or show_tooltip:
             self.osd = Osd(password=password, username=options["user"], address=options["address"], parent=self)
             self.osd.show()
             if show_tooltip:
                 # If tooltip == True then we just want to show password
                 return True
         # Prepare to launch command
-        if self.settings.value("protocols/" + protocol + "/command").toString():
+        command = unicode(self.settings.value("protocols/" + protocol + "/command").toString())
+        if command:
             # Create Command
+            args = unicode(self.settings.value("protocols/" + protocol + "/args").toString())
             command = unicode(self.settings.value("protocols/" + protocol + "/command").toString())
-            command = command % options
-            print command
+            args = args % options
+            print " ".join([command, args])
+            args = [QtCore.QString(arg) for arg in args.split(" ")]
+            args_list = QtCore.QStringList(args)
              
             # Exit if command is empty (to prevent segfault. See bug #4)
             if command.strip() == "": return
             # Launch process
             self.procxterm = QtCore.QProcess()
-            self.procxterm.start(command)
+            self.procxterm.start(command, args_list)
 
     def copyToClip(self, password):
         """
@@ -572,7 +584,10 @@ class MainWindow(QtGui.QMainWindow):
         indexId = self.tree.selectedIndexes()[1]
         index = self.tree.selectedIndexes()[0]
         itemid = indexId.data(QtCore.Qt.DisplayRole).toString()
-        itemid = int(itemid.split("#")[1])
+        try:
+            itemid = int(itemid.split("#")[1])
+        except ValueError, e:
+            return False
         # Check if seleted item is a service
         if index.parent().parent().isValid():
             self.editService(itemid)
@@ -611,7 +626,10 @@ class MainWindow(QtGui.QMainWindow):
         indexId = self.tree.selectedIndexes()[1]
         index = self.tree.selectedIndexes()[0]
         itemid = indexId.data(QtCore.Qt.DisplayRole).toString()
-        itemid = int(itemid.split("#")[1])
+        try:
+            itemid = int(itemid.split("#")[1])
+        except ValueError, e:
+            return False
         # Check if seleted item is a service
         if index.parent().parent().isValid():
             self.delService(itemid)
@@ -642,7 +660,10 @@ class MainWindow(QtGui.QMainWindow):
         indexId = self.tree.selectedIndexes()[1]
         index = self.tree.selectedIndexes()[0]
         machid = indexId.data(QtCore.Qt.DisplayRole).toString()
-        machid = int(machid.split("#")[1])
+        try:
+            machid = int(machid.split("#")[1])
+        except ValueError, e:
+            return False
         self.addservice = EditServiceWidget(False, machid, parent=self)
         self.addservice.exec_()
 
